import unittest
from israelrailapi import api

TEST_API_NAME = 'MyApi'
TEST_PARAMS = {'required': {},
               'notRequired': {'required': False},
               'default': {'default': 5}
               }


def _route_part_data(eta_diff_times=...):
    data = {
        'orignStation': 3600,
        'destinationStation': 3700,
        'arrivalTime': '01/01/2026 10:30:00',
        'departureTime': '01/01/2026 10:00:00',
        'originPlatform': 1,
        'destPlatform': 2,
    }
    if eta_diff_times is not ...:
        data['etaDiffTimes'] = eta_diff_times
    return data


class ApiTest(unittest.TestCase):
    def setUp(self) -> None:
        super().setUp()
        self.rail_test = api.IsraelRailApi(TEST_API_NAME, TEST_PARAMS)

    def test_setup(self):
        self.assertEqual(self.rail_test.url, api.API_BASE + "/" + TEST_API_NAME)

    def test_request_args(self):
        result = self.rail_test.prepare_arguments({'required': 'Hello'})
        self.assertEqual(result, {'required': 'Hello', 'default': 5})
        with self.assertRaises(KeyError):
            self.rail_test.prepare_arguments({'notRequired': 'Hello'})

        with self.assertRaises(KeyError):
            self.rail_test.prepare_arguments({'required': 'Hello', 'notRequired': 'Hello', 'random': 7})


class TrainRoutePartTest(unittest.TestCase):
    def test_departure_delay_matching_station(self):
        data = _route_part_data(eta_diff_times=[
            {'stationId': 9999, 'difMin': 2},
            {'stationId': 3600, 'difMin': 5},
        ])
        part = api.TrainRoutePart(data)
        self.assertEqual(part.departure_delay, 5)

    def test_departure_delay_no_matching_station(self):
        data = _route_part_data(eta_diff_times=[{'stationId': 9999, 'difMin': 7}])
        part = api.TrainRoutePart(data)
        self.assertEqual(part.departure_delay, 0)

    def test_departure_delay_empty_list(self):
        data = _route_part_data(eta_diff_times=[])
        part = api.TrainRoutePart(data)
        self.assertEqual(part.departure_delay, 0)

    def test_departure_delay_missing_key(self):
        data = _route_part_data()
        part = api.TrainRoutePart(data)
        self.assertEqual(part.departure_delay, 0)


if __name__ == '__main__':
    unittest.main()



import unittest
from israelrailapi import train_station

KNOWN_STATIONS = {'Jerusalem- yitzhak navon': 680, 'Dimona': 7500}


class ApiTest(unittest.TestCase):
    def test_station_lookup(self):
        # Testing known stations, not ideal but...
        for name, station_id in KNOWN_STATIONS.items():
            self.assertEqual(str(station_id), train_station.lookup_station(name))

    def failed_station_lookup(self):
        with self.assertRaises(KeyError):
            train_station.lookup_station('NY Penn')

        with self.assertRaises(KeyError):
            train_station.lookup_station['-700']


if __name__ == '__main__':
    unittest.main()



import israelrailapi.schedule
import israelrailapi.train_station
import israelrailapi.api
try:
    import israelrailapi.stations
except ImportError:
    pass

from .schedule import TrainSchedule

__all__ = ['TrainSchedule']



import logging
import sys
import time

from israelrailapi.api import GetRoutesApi
from israelrailapi.train_station import translate_station


class TrainSchedule(object):
    @staticmethod
    def query(src_station, dst_station, start_date=None, start_hour=None):
        src_station = translate_station(src_station)
        dst_station = translate_station(dst_station)
        if start_date is None:
            start_date = time.strftime("%Y-%m-%d")
        if start_hour is None:
            start_hour = "09:00"
        start_date = start_date.strip().replace('-', '').replace('/', '').replace('.', '')
        start_hour = start_hour.strip().replace(':', '').replace('-', '')
        start_hour = f"{start_hour[:2]}:{start_hour[2:]}"
        start_date = f"{start_date[:4]}-{start_date[4:6]}-{start_date[6:8]}"

        logging.info("Query: %s->%s (%s %s)" % (src_station, dst_station,
                                                start_date, start_hour))
        result = GetRoutesApi().request(fromStation=src_station, toStation=dst_station,
                                        date=start_date, hour=start_hour)
        logging.info(result)
        return result


if '__main__' == __name__:
    logging.basicConfig(level=logging.DEBUG)
    t = TrainSchedule()
    if len(sys.argv) == 5:
        q = t.query(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])
        print(q)
    else:
        print("Usage: %s <src> <dst> <YYYY-MM-DD> <hh:mm>" % (sys.argv[0],))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import json
import os

from setuptools import setup


def make_stations():
    with open(os.path.join(os.path.split(__file__)[0], 'stations.txt'),
              'r', encoding='utf8') as station_file:
        def cleanup_name(n):
            n = n.lower().strip().replace('\'', '').replace('-', ' ')
            return ' '.join(n.split())

        raw = json.load(station_file)['Data']['Data']['CustomPropertys']
        stations = {x.pop('Id'): {l: n[0] for l, n in x.items()} for x in raw}
        # Create reverse dict for indexed query
        station_index = {}
        for st in stations:
            for n in stations[st].values():
                station_index[cleanup_name(n)] = st
    open('israelrailapi/stations.py', 'w', encoding='utf8').write("""#!/usr/bin/env python
# -*- coding: utf-8 -*-

STATIONS = %s
STATION_INDEX = %s
""" % (repr(stations), repr(station_index)))


make_stations()

setup(
    name='israel-rail-api',
    version='0.1.5',
    packages=['israelrailapi'],
    url='https://github.com/sh0oki/israel-rail-api',
    install_requires=['requests',
                      'pytz'],
    license='MIT',
    author='sh0oki',
    description='Israeli Rail unofficial API',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown'
)



import time

import requests

from israelrailapi.train_station import station_name_to_id

# API key bundled in main.js of rail.co.il
API_KEY = "5e64d66cf03f4547bcac5de2de06b566"

USER_AGENT = (
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/17.0 "
    "Safari/605.1.15"
)
API_BASE = "https://rail-api.rail.co.il/rjpa/api/v1"
DEFAULT_HEADERS = {
    "User-Agent": USER_AGENT,
    "ocp-apim-subscription-key": API_KEY,
    "Content-Type": "application/json",
}


class TrainRoutePart(object):
    def __init__(self, data):
        self.data = data

        self.src = data['orignStation']
        self.dst = data['destinationStation']
        self.arrival = data['arrivalTime']
        self.departure = data['departureTime']
        self.platform = data['originPlatform']
        self.dst_platform = data['destPlatform']
        self.departure_delay = next(
            (e['difMin'] for e in data.get('etaDiffTimes', []) if e['stationId'] == self.src),
            0,
        )

    @staticmethod
    def parse_time(t):
        return time.strptime(t, "%d/%m/%Y %H:%M:%S")

    def __repr__(self):
        return "%s (%s) to %s (%s)" % (
            station_name_to_id(self.src), self.departure, station_name_to_id(self.dst), self.arrival)


class TrainRoute(object):
    def __init__(self, data):
        self.trains = self.parse(data)

        self.start_time = self.trains[0].departure
        self.end_time = self.trains[-1].arrival

    @staticmethod
    def parse(data):
        result = []
        for t in data:
            result.append(TrainRoutePart(t))
        return result

    def __repr__(self):
        return "%d trains in route, starting %s, arriving %s: %s\n" % (len(self.trains),
                                                                       self.start_time,
                                                                       self.end_time,
                                                                       self.trains)


class IsraelRailApi(object):
    def __init__(self, url, params, headers=None):
        self.arguments = None
        if headers is None:
            headers = DEFAULT_HEADERS
        self.url = '/'.join((API_BASE, url))
        self.params = params
        self.headers = headers

    def prepare_arguments(self, arguments):
        unknown_args = arguments.keys() - self.params.keys()
        if len(unknown_args) > 0:
            raise KeyError('Unknown arguments %s' % (unknown_args,))

        for k in self.params:
            if k not in arguments:
                if 'default' in self.params[k]:
                    arguments[k] = self.params[k]['default']
                elif self.params[k]['required'] is not False:
                    raise KeyError('Required argument %s not provided' % (k,))

        return arguments

    def parse(self, result):
        return result

    def request(self, **kwargs):
        self.arguments = self.prepare_arguments(kwargs)
        return self.parse(
            requests.post(self.url, json=self.arguments, headers=self.headers)
        )


class GetRoutesApi(IsraelRailApi):
    def __init__(self):
        super().__init__(
            "timetable/searchTrain",
            {
                "fromStation": {},
                "toStation": {},
                "date": {},
                "hour": {"default": "09:00"},
                "scheduleType": {"default": "ByDeparture"},
                "systemType": {"default": "2"},
                "languageId": {"default": "English"},
            },
        )

    def parse(self, raw_result):
        raw_result.raise_for_status()
        result = raw_result.json()['result']
        size = result['numOfResultsToShow']
        index = result['startFromIndex']

        routes = result['travels'][index: index + size]
        return [TrainRoute(r['trains']) for r in routes]



import logging

try:
    from israelrailapi.stations import STATIONS, STATION_INDEX
except ImportError:
    logging.warning("Unable to load station list")
    from stations import STATIONS, STATION_INDEX


def cleanup_name(n):
    n = n.lower().strip().replace('\'', '').replace('-', ' ')
    return ' '.join(n.split())


def lookup_station(n):
    return STATION_INDEX[cleanup_name(n)]


def translate_station(station_name):
    # Station name can be: int (station id), string (station id), string (station name)
    station_name = str(station_name).lower()
    if station_name in STATIONS:
        return STATIONS.stations[station_name]

    return lookup_station(station_name)


def station_name_to_id(station_id, default_language='Eng'):
    return STATIONS[str(station_id)][default_language]


if __name__ == '__main__':
    print(STATION_INDEX)
